Class: Google::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1LabelAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1beta2/classes.rb,
lib/google/apis/videointelligence_v1beta2/representations.rb,
lib/google/apis/videointelligence_v1beta2/representations.rb

Overview

Label annotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1LabelAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1LabelAnnotation.



389
390
391
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 389

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#category_entitiesArray<Google::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1Entity>

Common categories for the detected entity. For example, when the label is Terrier, the category is likely dog. And in some cases there might be more than one categories e.g., Terrier could also be a pet. Corresponds to the JSON property categoryEntities



367
368
369
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 367

def category_entities
  @category_entities
end

#entityGoogle::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1Entity

Detected entity from video analysis. Corresponds to the JSON property entity



372
373
374
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 372

def entity
  @entity
end

#framesArray<Google::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1LabelFrame>

All video frames where a label was detected. Corresponds to the JSON property frames



377
378
379
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 377

def frames
  @frames
end

#segmentsArray<Google::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1LabelSegment>

All video segments where a label was detected. Corresponds to the JSON property segments



382
383
384
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 382

def segments
  @segments
end

#versionString

Feature version. Corresponds to the JSON property version

Returns:

  • (String)


387
388
389
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 387

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



394
395
396
397
398
399
400
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 394

def update!(**args)
  @category_entities = args[:category_entities] if args.key?(:category_entities)
  @entity = args[:entity] if args.key?(:entity)
  @frames = args[:frames] if args.key?(:frames)
  @segments = args[:segments] if args.key?(:segments)
  @version = args[:version] if args.key?(:version)
end