Class: Google::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2ExplicitContentAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1beta2/classes.rb,
lib/google/apis/videointelligence_v1beta2/representations.rb,
lib/google/apis/videointelligence_v1beta2/representations.rb

Overview

Explicit content annotation (based on per-frame visual signals only). If no explicit content has been detected in a frame, no annotations are present for that frame.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2ExplicitContentAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1beta2ExplicitContentAnnotation.



1436
1437
1438
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 1436

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#framesArray<Google::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2ExplicitContentFrame>

All video frames where explicit content was detected. Corresponds to the JSON property frames



1429
1430
1431
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 1429

def frames
  @frames
end

#versionString

Feature version. Corresponds to the JSON property version

Returns:

  • (String)


1434
1435
1436
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 1434

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1441
1442
1443
1444
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 1441

def update!(**args)
  @frames = args[:frames] if args.key?(:frames)
  @version = args[:version] if args.key?(:version)
end