Class: Google::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2LabelAnnotation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1beta2/classes.rb,
lib/google/apis/videointelligence_v1beta2/representations.rb,
lib/google/apis/videointelligence_v1beta2/representations.rb

Overview

Label annotation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2LabelAnnotation

Returns a new instance of GoogleCloudVideointelligenceV1beta2LabelAnnotation.



1699
1700
1701
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 1699

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#category_entitiesArray<Google::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2Entity>

Common categories for the detected entity. For example, when the label is Terrier, the category is likely dog. And in some cases there might be more than one categories e.g., Terrier could also be a pet. Corresponds to the JSON property categoryEntities



1677
1678
1679
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 1677

def category_entities
  @category_entities
end

#entityGoogle::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2Entity

Detected entity from video analysis. Corresponds to the JSON property entity



1682
1683
1684
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 1682

def entity
  @entity
end

#framesArray<Google::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2LabelFrame>

All video frames where a label was detected. Corresponds to the JSON property frames



1687
1688
1689
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 1687

def frames
  @frames
end

#segmentsArray<Google::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2LabelSegment>

All video segments where a label was detected. Corresponds to the JSON property segments



1692
1693
1694
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 1692

def segments
  @segments
end

#versionString

Feature version. Corresponds to the JSON property version

Returns:

  • (String)


1697
1698
1699
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 1697

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1704
1705
1706
1707
1708
1709
1710
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 1704

def update!(**args)
  @category_entities = args[:category_entities] if args.key?(:category_entities)
  @entity = args[:entity] if args.key?(:entity)
  @frames = args[:frames] if args.key?(:frames)
  @segments = args[:segments] if args.key?(:segments)
  @version = args[:version] if args.key?(:version)
end