Class: Google::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2NormalizedBoundingPoly

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1beta2/classes.rb,
lib/google/apis/videointelligence_v1beta2/representations.rb,
lib/google/apis/videointelligence_v1beta2/representations.rb

Overview

Normalized bounding polygon for text (that might not be aligned with axis). Contains list of the corner points in clockwise order starting from top-left corner. For example, for a rectangular bounding box: When the text is horizontal it might look like: 0----1 | | 3----2 When it's clockwise rotated 180 degrees around the top-left corner it becomes: 2----3 | | 1----0 and the vertex order will still be (0, 1, 2, 3). Note that values can be less than 0, or greater than 1 due to trigonometric calculations for location of the box.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2NormalizedBoundingPoly

Returns a new instance of GoogleCloudVideointelligenceV1beta2NormalizedBoundingPoly.



1906
1907
1908
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 1906

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#verticesArray<Google::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2NormalizedVertex>

Normalized vertices of the bounding polygon. Corresponds to the JSON property vertices



1904
1905
1906
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 1904

def vertices
  @vertices
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1911
1912
1913
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 1911

def update!(**args)
  @vertices = args[:vertices] if args.key?(:vertices)
end