Class: Google::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2SpeechContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1beta2/classes.rb,
lib/google/apis/videointelligence_v1beta2/representations.rb,
lib/google/apis/videointelligence_v1beta2/representations.rb

Overview

Provides "hints" to the speech recognizer to favor specific words and phrases in the results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2SpeechContext

Returns a new instance of GoogleCloudVideointelligenceV1beta2SpeechContext.



2142
2143
2144
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2142

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#phrasesArray<String>

Optional. A list of strings containing words and phrases "hints" so that the speech recognition is more likely to recognize them. This can be used to improve the accuracy for specific words and phrases, for example, if specific commands are typically spoken by the user. This can also be used to add additional words to the vocabulary of the recognizer. See usage limits. Corresponds to the JSON property phrases

Returns:

  • (Array<String>)


2140
2141
2142
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2140

def phrases
  @phrases
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2147
2148
2149
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2147

def update!(**args)
  @phrases = args[:phrases] if args.key?(:phrases)
end