Class: Google::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2SpeechTranscription
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2SpeechTranscription
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1beta2/classes.rb,
lib/google/apis/videointelligence_v1beta2/representations.rb,
lib/google/apis/videointelligence_v1beta2/representations.rb
Overview
A speech recognition result corresponding to a portion of the audio.
Instance Attribute Summary collapse
-
#alternatives ⇒ Array<Google::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2SpeechRecognitionAlternative>
May contain one or more recognition hypotheses (up to the maximum specified in
max_alternatives). -
#language_code ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2SpeechTranscription
constructor
A new instance of GoogleCloudVideointelligenceV1beta2SpeechTranscription.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2SpeechTranscription
Returns a new instance of GoogleCloudVideointelligenceV1beta2SpeechTranscription.
2209 2210 2211 |
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2209 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alternatives ⇒ Array<Google::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2SpeechRecognitionAlternative>
May contain one or more recognition hypotheses (up to the maximum specified in
max_alternatives). These alternatives are ordered in terms of accuracy, with
the top (first) alternative being the most probable, as ranked by the
recognizer.
Corresponds to the JSON property alternatives
2200 2201 2202 |
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2200 def alternatives @alternatives end |
#language_code ⇒ String
Output only. The BCP-47
language tag of the language in this result. This language code was detected
to have the most likelihood of being spoken in the audio.
Corresponds to the JSON property languageCode
2207 2208 2209 |
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2207 def language_code @language_code end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2214 2215 2216 2217 |
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2214 def update!(**args) @alternatives = args[:alternatives] if args.key?(:alternatives) @language_code = args[:language_code] if args.key?(:language_code) end |