Class: Google::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2TextDetectionConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1beta2/classes.rb,
lib/google/apis/videointelligence_v1beta2/representations.rb,
lib/google/apis/videointelligence_v1beta2/representations.rb

Overview

Config for TEXT_DETECTION.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2TextDetectionConfig

Returns a new instance of GoogleCloudVideointelligenceV1beta2TextDetectionConfig.



2373
2374
2375
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2373

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#language_hintsArray<String>

Language hint can be specified if the language to be detected is known a priori. It can increase the accuracy of the detection. Language hint must be language code in BCP-47 format. Automatic language detection is performed if no hint is provided. Corresponds to the JSON property languageHints

Returns:

  • (Array<String>)


2365
2366
2367
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2365

def language_hints
  @language_hints
end

#modelString

Model to use for text detection. Supported values: "builtin/stable" (the default if unset) and "builtin/latest". Corresponds to the JSON property model

Returns:

  • (String)


2371
2372
2373
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2371

def model
  @model
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2378
2379
2380
2381
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2378

def update!(**args)
  @language_hints = args[:language_hints] if args.key?(:language_hints)
  @model = args[:model] if args.key?(:model)
end