Class: Google::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2TimestampedObject

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1beta2/classes.rb,
lib/google/apis/videointelligence_v1beta2/representations.rb,
lib/google/apis/videointelligence_v1beta2/representations.rb

Overview

For tracking related features. An object at time_offset with attributes, and located with normalized_bounding_box.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2TimestampedObject

Returns a new instance of GoogleCloudVideointelligenceV1beta2TimestampedObject.



2476
2477
2478
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2476

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesArray<Google::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2DetectedAttribute>

Optional. The attributes of the object in the bounding box. Corresponds to the JSON property attributes



2457
2458
2459
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2457

def attributes
  @attributes
end

#landmarksArray<Google::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2DetectedLandmark>

Optional. The detected landmarks. Corresponds to the JSON property landmarks



2462
2463
2464
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2462

def landmarks
  @landmarks
end

#normalized_bounding_boxGoogle::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2NormalizedBoundingBox

Normalized bounding box. The normalized vertex coordinates are relative to the original image. Range: [0, 1]. Corresponds to the JSON property normalizedBoundingBox



2468
2469
2470
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2468

def normalized_bounding_box
  @normalized_bounding_box
end

#time_offsetString

Time-offset, relative to the beginning of the video, corresponding to the video frame for this object. Corresponds to the JSON property timeOffset

Returns:

  • (String)


2474
2475
2476
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2474

def time_offset
  @time_offset
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2481
2482
2483
2484
2485
2486
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2481

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
  @landmarks = args[:landmarks] if args.key?(:landmarks)
  @normalized_bounding_box = args[:normalized_bounding_box] if args.key?(:normalized_bounding_box)
  @time_offset = args[:time_offset] if args.key?(:time_offset)
end