Class: Google::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2VideoContext

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/videointelligence_v1beta2/classes.rb,
lib/google/apis/videointelligence_v1beta2/representations.rb,
lib/google/apis/videointelligence_v1beta2/representations.rb

Overview

Video context and/or feature-specific parameters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2VideoContext

Returns a new instance of GoogleCloudVideointelligenceV1beta2VideoContext.



2769
2770
2771
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2769

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#explicit_content_detection_configGoogle::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2ExplicitContentDetectionConfig

Config for EXPLICIT_CONTENT_DETECTION. Corresponds to the JSON property explicitContentDetectionConfig



2725
2726
2727
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2725

def explicit_content_detection_config
  @explicit_content_detection_config
end

#face_detection_configGoogle::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2FaceDetectionConfig

Config for FACE_DETECTION. Corresponds to the JSON property faceDetectionConfig



2730
2731
2732
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2730

def face_detection_config
  @face_detection_config
end

#label_detection_configGoogle::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2LabelDetectionConfig

Config for LABEL_DETECTION. Corresponds to the JSON property labelDetectionConfig



2735
2736
2737
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2735

def label_detection_config
  @label_detection_config
end

#object_tracking_configGoogle::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2ObjectTrackingConfig

Config for OBJECT_TRACKING. Corresponds to the JSON property objectTrackingConfig



2740
2741
2742
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2740

def object_tracking_config
  @object_tracking_config
end

#person_detection_configGoogle::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2PersonDetectionConfig

Config for PERSON_DETECTION. Corresponds to the JSON property personDetectionConfig



2745
2746
2747
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2745

def person_detection_config
  @person_detection_config
end

#segmentsArray<Google::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2VideoSegment>

Video segments to annotate. The segments may overlap and are not required to be contiguous or span the whole video. If unspecified, each video is treated as a single segment. Corresponds to the JSON property segments



2752
2753
2754
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2752

def segments
  @segments
end

#shot_change_detection_configGoogle::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2ShotChangeDetectionConfig

Config for SHOT_CHANGE_DETECTION. Corresponds to the JSON property shotChangeDetectionConfig



2757
2758
2759
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2757

def shot_change_detection_config
  @shot_change_detection_config
end

#speech_transcription_configGoogle::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2SpeechTranscriptionConfig

Config for SPEECH_TRANSCRIPTION. Corresponds to the JSON property speechTranscriptionConfig



2762
2763
2764
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2762

def speech_transcription_config
  @speech_transcription_config
end

#text_detection_configGoogle::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2TextDetectionConfig

Config for TEXT_DETECTION. Corresponds to the JSON property textDetectionConfig



2767
2768
2769
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2767

def text_detection_config
  @text_detection_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2774
2775
2776
2777
2778
2779
2780
2781
2782
2783
2784
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 2774

def update!(**args)
  @explicit_content_detection_config = args[:explicit_content_detection_config] if args.key?(:explicit_content_detection_config)
  @face_detection_config = args[:face_detection_config] if args.key?(:face_detection_config)
  @label_detection_config = args[:label_detection_config] if args.key?(:label_detection_config)
  @object_tracking_config = args[:object_tracking_config] if args.key?(:object_tracking_config)
  @person_detection_config = args[:person_detection_config] if args.key?(:person_detection_config)
  @segments = args[:segments] if args.key?(:segments)
  @shot_change_detection_config = args[:shot_change_detection_config] if args.key?(:shot_change_detection_config)
  @speech_transcription_config = args[:speech_transcription_config] if args.key?(:speech_transcription_config)
  @text_detection_config = args[:text_detection_config] if args.key?(:text_detection_config)
end