Class: Google::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2ExportToOutputUriStatus
- Inherits:
-
Object
- Object
- Google::Apis::VideointelligenceV1beta2::GoogleCloudVideointelligenceV1beta2ExportToOutputUriStatus
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/videointelligence_v1beta2/classes.rb,
lib/google/apis/videointelligence_v1beta2/representations.rb,
lib/google/apis/videointelligence_v1beta2/representations.rb
Overview
Status of exporting annotation response to user specified output_uri.
Instance Attribute Summary collapse
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::VideointelligenceV1beta2::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2ExportToOutputUriStatus
constructor
A new instance of GoogleCloudVideointelligenceV1beta2ExportToOutputUriStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleCloudVideointelligenceV1beta2ExportToOutputUriStatus
Returns a new instance of GoogleCloudVideointelligenceV1beta2ExportToOutputUriStatus.
1512 1513 1514 |
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 1512 def initialize(**args) update!(**args) end |
Instance Attribute Details
#state ⇒ String
Output only. State of the output_uri export.
Corresponds to the JSON property state
1500 1501 1502 |
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 1500 def state @state end |
#status ⇒ Google::Apis::VideointelligenceV1beta2::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property status
1510 1511 1512 |
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 1510 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1517 1518 1519 1520 |
# File 'lib/google/apis/videointelligence_v1beta2/classes.rb', line 1517 def update!(**args) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) end |